import csv
from datetime import datetime
from pathlib import Path

from django.core.management.base import BaseCommand
from django.utils import timezone

from sat_automations.acs_journal.models import ACSJournal


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument(
            "--csv-file",
            help="File containing a list of Journal entries to create",
        )

    def handle(self, *args, **options):
        # get campus IDs from file
        csv_file = Path(options["csv_file"])
        if not csv_file.exists():
            self.stdout.write(
                self.style.WARNING(f"File {csv_file} does not exist. No Journal entries created.")
            )
            exit(0)
        # create tracker items
        self.stdout.write(self.style.SUCCESS(f"Importing Journal entries from {csv_file}..."))
        with csv_file.open("r") as csv_file:
            reader = csv.DictReader(csv_file)
            for line in reader:
                acs_journal = ACSJournal(
                    campus_id=line["campus_id"],
                    card_num=line["card_num"],
                    message_type=line["message_type"],
                    message_utc=timezone.make_aware(
                        datetime.strptime(line["message_utc"], "%Y-%m-%d %H:%M:%S.%f")
                    ),
                    server_utc=timezone.make_aware(
                        datetime.strptime(line["server_utc"], "%Y-%m-%d %H:%M:%S.%f")
                    ),
                    state_code=line["state_code"],
                    primary_object_name=line["primary_object_name"],
                    primary_object_type=line["primary_object_type"],
                    secondary_object_name=line["secondary_object_name"],
                    secondary_object_type=line["secondary_object_type"],
                )
                acs_journal.save()
