from django.core.management.base import BaseCommand

from sat_automations.acs_journal.models import ACSJournal
from sat_automations.acs_journal.tasks import AccessControlJournal
from sat_automations.utils.common.time import date_as_datetime


class Command(BaseCommand):
    """
    A command that will drop local journal entries and import new ones between the specified dates.
    The start-date will clear all entries greater than or equal to YYYY-MM-DD 00:00:00.
    THE end-date will clear all entries less than or equal to YYYY-MM-DD 23:59:59:99999.
    """

    def add_arguments(self, parser):
        parser.add_argument(
            "--start-date",
            help="The date in 'YYYY-MM-DD' to start the journal entries from. This is the date of the first entry.",
        )
        parser.add_argument(
            "--end-date",
            help="The date in 'YYYY-MM-DD' to end the journal entries. This is the date of the last entry.",
        )

    def handle(self, *args, **options):
        start = date_as_datetime(options["start_date"])
        end = date_as_datetime(options["end_date"])
        # delete any local entries between the start and end dates, so that we don't have duplicates
        ACSJournal.objects.filter(server_utc__gt=start, server_utc__lte=end).delete()
        # import the new entries
        acj = AccessControlJournal()
        acj._process_journal(start, end)
        self.stdout.write(self.style.SUCCESS(f"Journal repaired for {start} to {end}."))
