import pytest
from django.contrib.admin.sites import AdminSite

from sat_automations.acs_journal.admin import ACSJournalAdmin
from sat_automations.acs_journal.models import ACSJournal

pytestmark = pytest.mark.django_db


@pytest.fixture
def ma():
    return ACSJournalAdmin(ACSJournal, AdminSite())


def test_acs_journal_admin(ma):
    assert ma.list_display == [
        "message_type",
        "server_utc_str",
        "message_utc_str",
        "message_ltc",
        "campus_id",
        "card_num",
        "primary_object_name",
        "secondary_object_name",
        "state_code",
        "primary_type",
        "secondary_type",
    ]


def test_acs_journal_search_fields(ma):
    assert ma.search_fields == [
        "campus_id",
        "search_vector",
    ]


def test_acs_journal_readonly_fields(ma):
    assert ma.readonly_fields == [
        "message_type",
        "server_utc",
        "message_utc",
        "campus_id",
        "card_num",
        "primary_object_name",
        "primary_object_type",
        "primary_object_uuid",
        "secondary_object_name",
        "secondary_object_type",
        "secondary_object_uuid",
        "state_code",
        "search_vector",
    ]


def test_acs_journal_list_filter(ma, admin_client):
    filters = ma.get_list_filter(admin_client.request)
    class_filter = filters.pop()
    assert sorted(filters) == sorted(["state_code"])
    assert class_filter.__name__ == "MessageLTCFilter"
