from datetime import datetime, timedelta
from unittest.mock import MagicMock

import pytest

from sat_automations.acs_journal.models import ACSJournal
from sat_automations.acs_journal.tasks import AccessControlJournal

pytestmark = pytest.mark.django_db


@pytest.fixture
def standard_patch(patch_google_authenticate, patch_ccure_connection):
    patch_google_authenticate("acs_journal")
    patch_ccure_connection("acs_journal")


@pytest.fixture
def patch_query_journal(mocker):
    return mocker.patch("sat_automations.acs_journal.tasks.AccessControlJournal.query_journal")


def test_acs_journal_multiple_dts(random_acs_journal):
    acjs, _, _ = random_acs_journal(count=20, increment_by="minutes")
    assert acjs[0].message_utc < acjs[1].message_utc
    assert acjs[-2].message_utc < acjs[-1].message_utc


def test_acs_journal_query_journal(random_ccure_journal, patch_query_journal, standard_patch):
    acj = AccessControlJournal()
    results = random_ccure_journal(count=20, increment_by="minutes")
    acj.query_journal.return_value = results
    # The start and end dates don't matter, as we're mocking the query_journal method.
    # We need an end date that is greater than the start date, but small enough that we
    # only loop once.
    acj._process_journal(datetime.now(), datetime.now() + timedelta(minutes=2))
    assert ACSJournal.objects.all().count() == 20


def test_bad_times(standard_patch):
    acj = AccessControlJournal()
    start = datetime.now()
    end = datetime.now() - timedelta(days=1)
    acj._process_journal(start, end)
    assert ACSJournal.objects.all().count() == 0


def test_hourly_process(standard_patch, random_acs_journal):
    acj = AccessControlJournal()
    acj._process_journal = MagicMock()
    journals, _, _ = random_acs_journal(count=5, increment_by="seconds")
    acj.process_hourly_journal()
    calls = acj._process_journal.call_args_list
    assert calls[0][0][0] == journals[-1].server_utc
