from datetime import datetime

import pytest

from sat_automations.acs_journal.admin import bound_time
from sat_automations.acs_journal.models import ACSJournal
from sat_automations.conftest import ACS_JOURNAL_CHOICES
from sat_automations.utils.common.time import SATTimeZones

pytestmark = pytest.mark.django_db


def test_random_acs_journal_model(random_acs_journal):
    raj, _, _ = random_acs_journal()
    today = bound_time(datetime.now()).replace(tzinfo=SATTimeZones.UTC.value)
    assert isinstance(raj, ACSJournal)
    assert raj.message_utc <= today
    assert raj.server_utc <= today
    assert raj.state_code in ACS_JOURNAL_CHOICES.get("state_code")
    assert raj.primary_object_type in ACS_JOURNAL_CHOICES.get("primary_object_type")
    assert raj.secondary_object_type in ACS_JOURNAL_CHOICES.get("secondary_object_type")
    raj.save()
    assert ACSJournal.objects.count() == 1


def test_acs_journal_model_types(random_acs_journal):
    raj, _, _ = random_acs_journal()
    primary = raj.primary_object_type.split(".")[-1]
    secondary = raj.secondary_object_type.split(".")[-1]
    assert raj.primary_type() == primary
    assert raj.secondary_type() == secondary


def test_types_work_with_empty_values(random_acs_journal):
    raj, _, _ = random_acs_journal()
    raj.primary_object_type = ""
    raj.secondary_object_type = ""
    assert raj.primary_type() == ""
    assert raj.secondary_type() == ""
