from django.contrib import admin
from django.db.models import JSONField
from django_json_widget.widgets import JSONEditorWidget

from sat_automations.affiliate_automation.models import Cardholder, CardRequest, Sponsor
from sat_automations.utils.mixins.admin import ExportCsvMixin


class HoldersInline(admin.TabularInline):
    model = CardRequest.cardholders.through
    readonly_fields = ["cardholder"]
    can_delete = False
    extra = 0


class SponsorAdmin(ExportCsvMixin, admin.ModelAdmin):
    list_display = ["name", "email", "unity_id"]

    ordering = ["name"]
    search_fields = ["name", "email", "unity_id"]
    actions = ExportCsvMixin.actions

    class Meta:
        model = Sponsor


class CardholderAdmin(ExportCsvMixin, admin.ModelAdmin):
    list_display = ["email", "first_name", "last_name"]
    ordering = ["email"]
    search_fields = ["first_name", "last_name", "email"]
    readonly_fields = [
        "email",
        "first_name",
        "last_name",
        "campus_id",
    ]
    actions = ExportCsvMixin.actions

    class Meta:
        model = Cardholder


class CardRequestAdmin(ExportCsvMixin, admin.ModelAdmin):
    formfield_overrides = {
        JSONField: {"widget": JSONEditorWidget},
    }
    list_display = ["date_created", "sponsor", "card_type"]
    list_filter = ["card_type", "date_created"]
    ordering = ["-date_created"]
    search_fields = ["sponsor__name", "sponsor__email"]

    readonly_fields = ["sponsor", "card_type", "date_created"]

    inlines = [HoldersInline]
    exclude = ["cardholders"]

    actions = ExportCsvMixin.actions

    class Meta:
        model = CardRequest


admin.site.register(Cardholder, CardholderAdmin)
admin.site.register(CardRequest, CardRequestAdmin)
admin.site.register(Sponsor, SponsorAdmin)
