from django.core.management.base import BaseCommand
from sat.gravity_forms import GravityForms

from sat_automations.affiliate_automation.models import Cardholder, CardRequest


class Command(BaseCommand):
    def handle(self, *args, **options):
        gravity_forms = GravityForms()
        cr_objs = CardRequest.objects.all()
        self.stdout.write(
            self.style.SUCCESS(
                f"Updating the card holder campus_id for {cr_objs.count()} CardRequests."
            )
        )
        updated_cardholders = 0
        cardholders_with_no_id = []
        for obj in cr_objs:
            if ids := obj.details.get("32"):
                for aff_id in ids.split(","):
                    cardholder_data = gravity_forms.get_entry(aff_id)
                    if cardholder := Cardholder.objects.filter(
                        email=cardholder_data.details["3"],
                        first_name=cardholder_data.details["2.3"],
                        last_name=cardholder_data.details["2.6"],
                    ).first():
                        if campus_id := cardholder_data.details.get("4"):
                            self.stdout.write(
                                self.style.SUCCESS(
                                    f"Updating campus_id ({campus_id}) for {cardholder}"
                                )
                            )
                            cardholder.campus_id = campus_id
                            cardholder.save()
                            updated_cardholders += 1
                        else:
                            cardholders_with_no_id.append(f"{cardholder.pk}: {cardholder}")
        self.stdout.write(self.style.SUCCESS(f"Campus IDs updated: {updated_cardholders}."))
        self.stdout.write(
            self.style.SUCCESS(f"Cardholders with no campus_id: {cardholders_with_no_id}")
        )
