from django.db import models
from model_utils.models import TimeStampedModel


class Sponsor(TimeStampedModel):
    name = models.CharField(max_length=512)
    email = models.EmailField()
    unity_id = models.CharField(max_length=128)

    def __str__(self):
        return self.name

    class Meta:
        unique_together = ["email", "unity_id"]
        indexes = [models.Index(fields=["name", "email"])]


class CardRequest(TimeStampedModel):
    class CardTypes(models.TextChoices):
        VISITOR = "VI", "Visitor"
        AFFILIATE = "AF", "Affiliate"
        CORPORATE_PARTNER = "CP", "Corporate Partner"
        CONTRACTOR = "CO", "Contractor"
        VISITOR_SELF_PAY = "VS", "Visitor (Self Pay)"

    date_created = models.DateTimeField(null=True)
    sponsor = models.ForeignKey(Sponsor, on_delete=models.CASCADE)
    card_type = models.CharField(
        max_length=max(len(x) for x in CardTypes.values),
        choices=CardTypes.choices,
        blank=False,
        null=False,
    )
    details = models.JSONField(null=True)
    cardholders = models.ManyToManyField("Cardholder")

    def __str__(self):
        return f"{self.CardTypes(self.card_type).name} request by {self.sponsor.name}"

    class Meta:
        indexes = [models.Index(fields=["sponsor", "card_type"])]


class Cardholder(TimeStampedModel):
    first_name = models.CharField(max_length=128)
    last_name = models.CharField(max_length=128)
    email = models.EmailField()
    campus_id = models.CharField(max_length=9, null=True)
    ccure_id = models.IntegerField(null=True)
    prox_id = models.IntegerField(null=True)

    def __str__(self):
        return f"{self.first_name} {self.last_name}"

    class Meta:
        indexes = [models.Index(fields=["first_name", "last_name", "email"])]
        unique_together = ["first_name", "last_name", "email", "campus_id"]
