import pytest
from django.contrib.admin.sites import AdminSite

from sat_automations.affiliate_automation.admin import (
    CardholderAdmin,
    CardRequestAdmin,
    SponsorAdmin,
)
from sat_automations.affiliate_automation.models import Cardholder, CardRequest, Sponsor

pytestmark = pytest.mark.django_db
admin_site = AdminSite()


@pytest.fixture
def sponsor_admin():
    return SponsorAdmin(Sponsor, admin_site)


@pytest.fixture
def cardholder_admin():
    return CardholderAdmin(Cardholder, admin_site)


@pytest.fixture
def card_request_admin():
    return CardRequestAdmin(CardRequest, admin_site)


SPONSOR_FIELDS = ["name", "email", "unity_id"]
CARDHOLDER_FIELDS = ["last_name", "first_name", "email", "campus_id", "ccure_id", "prox_id"]
CARD_REQUEST_FIELDS = ["sponsor", "details", "card_type", "date_created"]


def test_sponsor_fields(sponsor_admin, admin_client):
    assert sorted(sponsor_admin.get_fields(admin_client.request)) == sorted(SPONSOR_FIELDS)


def test_cardholder_fields(cardholder_admin, admin_client):
    assert sorted(cardholder_admin.get_fields(admin_client.request)) == sorted(CARDHOLDER_FIELDS)


def test_card_request_fields(card_request_admin, admin_client):
    assert sorted(card_request_admin.get_fields(admin_client.request)) == sorted(
        CARD_REQUEST_FIELDS
    )


def test_card_request_list_filter(card_request_admin, admin_client):
    filters = card_request_admin.get_list_filter(admin_client.request)
    assert sorted(filters) == sorted(["card_type", "date_created"])
