import pytest
from django.urls import reverse

pytestmark = pytest.mark.django_db


def test_housing_automation_log_list_view(client, random_assign_revoke_log):
    log = random_assign_revoke_log()
    log.save()
    url = reverse("arlog-list")
    response = client.get(url, format="json")
    assert response.status_code == 200
    assert len(response.json()) == 1
    obj_fields = [x.name for x in log._meta.fields]
    for key in response.json()[0].keys():
        assert key in obj_fields


def test_housing_automation_log_detail_view(client, random_assign_revoke_log):
    log = random_assign_revoke_log()
    log.save()
    url = reverse("arlog-detail", args=[log.pk])
    response = client.get(url, format="json")
    assert response.status_code == 200
    obj_fields = [x.name for x in log._meta.fields]
    for key in response.json().keys():
        assert key in obj_fields


def test_disablement_tracker_list(client, random_disablement_tracker):
    random_disablement_tracker.save()
    url = reverse("disablement-list")
    response = client.get(url, format="json")
    assert response.status_code == 200
    assert len(response.json()) == 1
    obj_fields = [x.name for x in random_disablement_tracker._meta.fields]
    for key in response.json()[0].keys():
        assert key in obj_fields


def test_disablement_tracker_detail(client, random_disablement_tracker):
    random_disablement_tracker.save()
    url = reverse("disablement-detail", args=[random_disablement_tracker.pk])
    response = client.get(url, format="json")
    assert response.status_code == 200
    obj_fields = [x.name for x in random_disablement_tracker._meta.fields]
    for key in response.json().keys():
        assert key in obj_fields


def test_affiliate_automation_sponsor_view(client, fake_card_request_sponsor):
    fake_card_request_sponsor.save()
    url = reverse("card-request-sponsor-list")
    response = client.get(url, format="json")
    assert response.status_code == 200
    assert len(response.json()) == 1
    obj_fields = [x.name for x in fake_card_request_sponsor._meta.fields]
    for key in response.json()[0].keys():
        assert key in obj_fields


def test_affiliate_automation_cardholder_view(client, fake_card_request_cardholders):
    for cardholder in fake_card_request_cardholders:
        cardholder.save()
    url = reverse("card-request-cardholder-list")
    response = client.get(url, format="json")
    assert response.status_code == 200
    assert len(response.json()) == 2
    obj_fields = [x.name for x in fake_card_request_cardholders[0]._meta.fields] + ["card_requests"]
    for key in response.json()[0].keys():
        assert key in obj_fields


def test_affiliate_automation_request_view(client, fake_card_request_request):
    fake_card_request_request.save()
    url = reverse("card-request-list")
    response = client.get(url, format="json")
    assert response.status_code == 200
    assert len(response.json()) == 1
    obj_fields = [x.name for x in fake_card_request_request._meta.fields] + ["cardholders"]
    for key in response.json()[0].keys():
        assert key in obj_fields
