from requests import Session

BASE_URL = "https://commander.ehps.ncsu.edu/api/v3"


def login_to_commander_instance(session: Session, username: str, password: str):
    response = session.put(f"{BASE_URL}/login", json={"Login": username, "Password": password})
    response.raise_for_status()
    return True


def get_2n_data(session: Session):
    response = session.get(f"{BASE_URL}/devices")
    response.raise_for_status()
    return response.json()


def normalize_mac_address(input_mac: str):
    """Normalizes incoming mac addresses to uppercase, alphanumeric, colon separated"""
    colon_separation_n = 2
    if not input_mac:
        return ""
    if "-" in input_mac:
        return input_mac.replace("-", ":").upper()
    elif ":" in input_mac:
        return input_mac.upper()
    else:
        return ":".join(
            input_mac[i : i + colon_separation_n]
            for i in range(0, len(input_mac), colon_separation_n)
        ).upper()
