import re

FLOOR_PATTERN = re.compile(r"(-|\s)(01|02|03|04|05|06|07|08|G|L|B1|B|B2)")
ABBREVIATION_PATTERN = re.compile(r"(\w+-+|\w+\s-)")
ROOM_PATTERN = re.compile(r"(\w+-+|\w+\s-)")


def _remove_floor_from_name(asset_name: str):
    match = FLOOR_PATTERN.search(asset_name)
    if match:
        return asset_name.replace(match.group(), "")
    else:
        return asset_name


def get_building_abbreviation_from_name(asset_name: str):
    """Derives the 3 letter building abbreviation from an asset name if one exists"""
    match = ABBREVIATION_PATTERN.search(asset_name)
    if match:
        description_group = match.group(1)
        cleaned_description = description_group.replace("-", "")
        stripped_description = cleaned_description.strip()
        return stripped_description
    else:
        return None


def get_room_number_from_name(asset_name: str):
    """Derives the room number from an asset name if one exists"""

    floor_removed_name = _remove_floor_from_name(asset_name)

    match = ROOM_PATTERN.findall(floor_removed_name)
    if len(match) > 2:
        room_match = match[1]
        cleaned_room = room_match.replace("-", "")
        stripped_room = cleaned_room.strip()
        return stripped_room
    else:
        return None
