import datetime

import pytest
from django.contrib.admin.sites import AdminSite

from sat_automations.disablement_automation.admin import DisablementTrackerAdmin
from sat_automations.disablement_automation.models import DisablementTracker

pytestmark = pytest.mark.django_db

DISABLEMENT_TRACKER_FIELDS = [
    "campus_id",
    "ccure_last_used",
    "ccure_object_id",
    "ccure_guid",
    "ccure_name",
    "ccure_personnel_id",
    "purge_on",
    "disable_type",
    "disabled_in_ccure",
    "ever_student",
    "peoplesoft_employee",
    "peoplesoft_status",
    "peoplesoft_student",
    "peoplesoft_effective_date",
    "peoplesoft_email",
    "emails_sent",
    "supervisor_id",
    "message",
    "peoplesoft_unity",
    "purged_from_ccure",
]

DISABLEMENT_LIST_DISPLAY = [
    "ccure_name",
    "campus_id",
    "peoplesoft_effective_date",
    "ccure_last_used",
    "peoplesoft_status",
    "disable_type",
    "modified",
    "disabled_in_ccure",
    "purge_on",
    "peoplesoft_student",
    "peoplesoft_employee",
    "peoplesoft_email",
    "ever_student",
]

DEFAULT_TRACKER = {
    "campus_id": "123456789",
    "ccure_object_id": 123456789,
    "ccure_guid": "123456789",
    "ccure_name": "Test, Test",
    "ccure_personnel_id": 123456789,
    "disabled_in_ccure": False,
    "disable_type": "Employee",
    "peoplesoft_status": "ACT",
    "peoplesoft_effective_date": datetime.datetime.strptime(
        "2021-01-01 00:00:00", "%Y-%m-%d %H:%M:%S"
    ),
}


@pytest.fixture
def ma():
    return DisablementTrackerAdmin(DisablementTracker, AdminSite())


@pytest.fixture
def create_tracker():
    def _create_tracker(**kwargs):
        return DisablementTracker.objects.create(**kwargs)

    return _create_tracker


def test_tracker_fields(ma, admin_client):
    assert sorted(ma.get_fields(admin_client.request)) == sorted(DISABLEMENT_TRACKER_FIELDS)


def test_tracker_list_display(ma, admin_client):
    assert sorted(ma.get_list_display(admin_client.request)) == sorted(DISABLEMENT_LIST_DISPLAY)


def test_tracker_search_fields(ma, admin_client):
    assert sorted(ma.get_search_fields(admin_client.request)) == sorted(
        ["campus_id", "ccure_name", "peoplesoft_unity"]
    )


def test_tracker_list_filter(ma, admin_client):
    filters = ma.get_list_filter(admin_client.request)
    class_filter = filters.pop()
    assert sorted(filters) == sorted(
        [
            "peoplesoft_status",
            "disabled_in_ccure",
            "disable_type",
            "purge_on",
            "peoplesoft_employee",
            "peoplesoft_student",
            "modified",
            "ever_student",
        ]
    )
    assert class_filter.__name__ == "LastUsedFilter"
