import datetime

import pytest

from sat_automations.conftest import Response
from sat_automations.disablement_automation.email import (
    send_disablement_message,
)

pytestmark = pytest.mark.django_db


def test_send_email_employee_supervisor_current(employee_supervisor, mock_sendgrid_client):
    employee, supervisor = employee_supervisor
    employee.purge_on = datetime.datetime.now().date()
    mock_sendgrid_client.send.return_value = Response()
    assert send_disablement_message(employee, supervisor=supervisor) is True
    assert mock_sendgrid_client.send.call_count == 2


def test_send_email_inactive_supervisor(employee_supervisor, mock_sendgrid_client):
    employee, supervisor = employee_supervisor
    employee.purge_on = datetime.datetime.now().date()
    supervisor.current_employee = "N"
    mock_sendgrid_client.send.return_value = Response()
    assert send_disablement_message(employee, supervisor=supervisor) is True
    assert mock_sendgrid_client.send.call_count == 1


def test_send_email_supervisor_no_email(employee_supervisor, mock_sendgrid_client):
    employee, supervisor = employee_supervisor
    employee.purge_on = datetime.datetime.now().date()
    supervisor.email = " "
    mock_sendgrid_client.send.return_value = Response()
    assert send_disablement_message(employee, supervisor=supervisor) is True
    assert mock_sendgrid_client.send.call_count == 1


def test_send_email_employee_no_supervisor(employee_supervisor, mock_sendgrid_client):
    employee, supervisor = employee_supervisor
    employee.purge_on = datetime.datetime.now().date()
    supervisor = None
    mock_sendgrid_client.send.return_value = Response()
    assert send_disablement_message(employee, supervisor=supervisor) is True
    assert mock_sendgrid_client.send.call_count == 1


def test_send_email_student(random_disablement_tracker, mock_sendgrid_client):
    mock_sendgrid_client.send.return_value = Response()
    assert send_disablement_message(random_disablement_tracker) is True
    assert mock_sendgrid_client.send.call_count == 1


def test_send_email_is_empty(random_disablement_tracker, mock_sendgrid_client):
    random_disablement_tracker.peoplesoft_email = " "
    assert send_disablement_message(random_disablement_tracker) is False
    assert mock_sendgrid_client.send.call_count == 0


def test_send_email_employee_fail(employee_supervisor, mock_sendgrid_client):
    # If the employee send fails, the supervisor email should not be sent
    employee, supervisor = employee_supervisor
    employee.purge_on = datetime.datetime.now().date()
    response = Response()
    response.status_code = 400
    mock_sendgrid_client.send.return_value = response
    assert send_disablement_message(employee, supervisor=supervisor) is False
    assert mock_sendgrid_client.send.call_count == 1


def test_send_email_student_fail(random_disablement_tracker, mock_sendgrid_client):
    response = Response()
    response.status_code = 400
    mock_sendgrid_client.send.return_value = response
    assert send_disablement_message(random_disablement_tracker) is False
    assert mock_sendgrid_client.send.call_count == 1
