# The views are primarily DRF viewsets, which are a combination of views and serializers.
# Path: sat_automations/api/urls.py
from rest_framework import serializers, viewsets

from sat_automations.disablement_automation.models import DisablementTracker


# Serializers define the API representation.
class DisablementSerializer(serializers.HyperlinkedModelSerializer):
    class Meta:
        model = DisablementTracker
        fields = [
            "id",
            "campus_id",
            "ccure_object_id",
            "ccure_guid",
            "ccure_name",
            "ccure_personnel_id",
            "ccure_last_used",
            "disabled_in_ccure",
            "peoplesoft_status",
            "peoplesoft_effective_date",
            "message",
            "created",
            "modified",
        ]


class DisablementViewSet(viewsets.ReadOnlyModelViewSet):
    """
    This viewset automatically provides `list` and `detail` actions.

    Usage:
    ------
    - `/api/v1/disablement/`
    - `/api/v1/disablement/?page=20`
    - `/api/v1/disablement/{id}`  # Note: The ID is the primary key, not the campus ID.
    """

    queryset = DisablementTracker.objects.all()
    serializer_class = DisablementSerializer
