import requests
from django.conf import settings

from sat_automations.housing_automation.models import PeopleSoftProxyBase


class PeopleSoftProxy(PeopleSoftProxyBase):
    def __init__(self, access_token) -> None:
        super().__init__(access_token=access_token)
        self.base_url = settings.PEOPLESOFT_PROXY_URL

    def get_person(self, campus_id):
        housing_search_url = f"{self.base_url}/people/housing/{campus_id}"
        response = requests.get(
            housing_search_url,
            headers={"Authorization": f"Bearer {self.access_token}"},
            timeout=600,
        )
        return response.json()

    def get_housing(self, days=90):
        housing_automation_url = f"{self.base_url}/people/housing/automation/{days}"
        response = requests.get(
            housing_automation_url,
            headers={"Authorization": f"Bearer {self.access_token}"},
            timeout=600,
        )
        return response.json()

    def get_active_students(self):
        peoplesoft_url = f"{self.base_url}/people/students"
        response = requests.get(
            peoplesoft_url,
            headers={"Authorization": f"Bearer {self.access_token}"},
            timeout=600,
        )
        return response.json()


class PeopleSoftProxyProvider:
    def __new__(cls, *args, **kwargs):
        return PeopleSoftProxy(*args, **kwargs)


AUTH_SERVICE_URL = settings.AUTH_SERVICE_URL
