import json

from django.core.management.base import BaseCommand

from sat_automations.housing_automation.models import Clearance, RoomUseCode


class Command(BaseCommand):
    """
    The command requires a command line argument whose value is the filepath to the clearance_map
    file.
    The file must be parsable as json in the format:
    ```json
    {
        "AFC - A-222-A": {
            "ObjectID": "6776",
            "GUID": "40D1E821-6B78-477B-B123-F0AA7497DBA8",
            "Name": "AFA-UH Aurora Fall/Spring-DEPT",
        },
        ...
    }
    ```

    Find the current file at
    https://drive.google.com/file/d/15YH_SX67U9glerbFckIYfZRNHgIxBRYG/view?usp=drive_link
    """

    def add_arguments(self, parser):
        parser.add_argument("file_path", type=str, help="Path to the clearance_map file")

    def handle(self, *args, **options):
        file_path = options["file_path"]
        with open(file_path) as f:
            clearance_map = json.load(f)

        for room_use_code, clearance in clearance_map.items():
            try:
                if clearance:
                    clearance_obj, _ = Clearance.objects.get_or_create(
                        name=clearance.get("Name"),
                        object_id=clearance.get("ObjectID"),
                    )
                else:
                    clearance_obj, _ = Clearance.objects.get_or_create(
                        name="NO_CLEARANCE_ASSIGNED",
                        object_id=0,
                    )
                RoomUseCode.objects.get_or_create(name=room_use_code, clearance=clearance_obj)
            except Exception as e:
                print(f"{e}: {room_use_code}: {clearance}")
