"""Populate new Clearance and RoomUseCode tables with data from clearance_map"""

# Generated by Django 4.2.2 on 2023-08-04 18:42

from django.conf import settings
from django.db import migrations

try:
    from sat_automations.housing_automation.data.clearance_map import clearance_map
except ImportError:
    print("ImportError: sat_automations.housing_automation.data.clearance_map not found.")
    # Add a couple of dummy entries to clearance_map, just in case someone tries to run this migration
    # without a backup database and without the clearance_map file.
    # NOTE: The file will be remove in a future commit tied to this ticket
    # https://ncstatesat.atlassian.net/browse/AUTM-29
    clearance_map = {
        "AFC - A-222-A": {
            "ObjectID": "6776",
            "GUID": "40D1E821-6B78-477B-B123-F0AA7497DBA8",
            "Name": "AFA-UH Aurora Fall/Spring-DEPT",
        },
        "AFC - A-224-A": {
            "ObjectID": "6776",
            "GUID": "40D1E821-6B78-477B-B123-F0AA7497DBA8",
            "Name": "AFA-UH Aurora Fall/Spring-DEPT",
        },
    }


def populate_clearances_and_roomusecodes(apps, _):
    """Populate Clearance and RoomUseCode tables with data from clearance_map"""
    Clearance = apps.get_model("housing_automation", "Clearance")
    RoomUseCode = apps.get_model("housing_automation", "RoomUseCode")
    no_clearance, _ = Clearance.objects.get_or_create(object_id=0, name="NC")
    for room_code, clearance_data in clearance_map.items():
        if isinstance(clearance_data, dict):
            clearance, _ = Clearance.objects.get_or_create(
                object_id=int(clearance_data["ObjectID"]), name=clearance_data["Name"]
            )
        else:
            clearance = no_clearance
        RoomUseCode.objects.create(clearance=clearance, name=room_code)


class Migration(migrations.Migration):
    """Run the migration functions"""

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("housing_automation", "0005_clearance_roomusecode_historicalclearance_and_more"),
    ]

    operations = [migrations.RunPython(populate_clearances_and_roomusecodes)]
