# Generated by Django 4.2.4 on 2023-11-06 18:47

from django.db import migrations


def populate_roomusecode_m2m_clearances(apps, schema_editor):
    """Populate the m2m_clearances field on RoomUseCode objects.

    This is a many-to-many field that was added in a previous migration, but
    was not populated. This migration populates it.
    """
    RoomUseCode = apps.get_model("housing_automation", "RoomUseCode")
    Clearance = apps.get_model("housing_automation", "Clearance")

    for roomusecode in RoomUseCode.objects.all():
        if clearance := Clearance.objects.filter(building_code__name=roomusecode.name).first():
            roomusecode.m2m_clearances.add(clearance)


def restore_roomusecode_m2m_clearances(apps, schema_editor):
    """Clear the m2m_clearances field on RoomUseCode objects.

    This is a many-to-many field that was added in a previous migration, but
    was not populated. This migration clears it.
    """
    RoomUseCode = apps.get_model("housing_automation", "RoomUseCode")

    for roomusecode in RoomUseCode.objects.all():
        roomusecode.m2m_clearances.clear()


class Migration(migrations.Migration):
    dependencies = [
        ("housing_automation", "0010_roomusecode_m2m_clearances"),
    ]

    operations = [
        migrations.RunPython(
            populate_roomusecode_m2m_clearances, reverse_code=restore_roomusecode_m2m_clearances
        )
    ]
