import datetime

import pytest
from bs4 import BeautifulSoup
from django.contrib.admin import AdminSite

from sat_automations.housing_automation.admin import ARLogAdmin
from sat_automations.housing_automation.models import ARLog, RoomUseCode

pytestmark = pytest.mark.django_db

TRACKER_FIELDS = [
    "campus_id",
    "building_code",
    "move_in_date",
    "move_out_date",
    "action_type",
    "status",
    "created",
    "modified",
]

LOG_FIELDS = [
    "campus_id",
    "action_date",
    "action_type",
    "peoplesoft_action_dttm",
    "ruc",
    "action_success",
    "action_message",
    "action_error_information",
    "req_status",
]

LOG_FIELDS_LIST_DISPLAY = [
    "campus_id",
    "get_ruc",
    "action_date",
    "action_type",
    "req_status",
    "action_success",
    "action_message",
    "peoplesoft_action_dttm",
    "created",
    "modified",
]


@pytest.fixture
def arl():
    return ARLogAdmin(ARLog, AdminSite())


@pytest.fixture
def ruc():
    obj, __ = RoomUseCode.objects.get_or_create(name="Test")
    return obj


@pytest.fixture
def assign_revoke_log(ruc):
    return ARLog(
        campus_id=123456789,
        action_date=datetime.datetime.now().date(),
        action_type="assign",
        peoplesoft_action_dttm=datetime.datetime.now(),
        ruc=ruc,
        action_success=None,
        action_message=None,
    )


def test_ha_log_fields(arl, admin_client):
    assert sorted(arl.get_fields(admin_client.request)) == sorted(LOG_FIELDS)


def test_ha_log_list_display(arl, admin_client):
    assert sorted(arl.get_list_display(admin_client.request)) == sorted(LOG_FIELDS_LIST_DISPLAY)


def test_ha_log_list_display_default_with_no_status(admin_client, assign_revoke_log):
    log = assign_revoke_log
    log.status = None
    log.save()
    response = admin_client.get("/admin/housing_automation/arlog/")
    soup = BeautifulSoup(response.content, "html.parser")
    element = soup.find("table", {"id": "result_list"})
    assert len(element.find_all("tr")) == 2  # 1 for header, 1 for data
