# The views are primarily DRF viewsets, which are a combination of views and serializers.
# Path: sat_automations/api/urls.py
from rest_framework import serializers, viewsets

from sat_automations.housing_automation.models import ARLog


class LogSerializer(serializers.HyperlinkedModelSerializer):
    ruc = serializers.StringRelatedField(many=False)

    class Meta:
        model = ARLog
        fields = [
            "id",
            "campus_id",
            "action_date",
            "action_type",
            "peoplesoft_action_dttm",
            "ruc",
            "action_success",
            "action_message",
            "req_status",
            "created",
            "modified",
        ]


class LogViewSet(viewsets.ReadOnlyModelViewSet):
    """
    This viewset automatically provides `list` and `detail` actions.

    Usage:
    ------
    - `/api/v1/assign-revoke/log/`
    - `/api/v1/assign-revoke/log/?page=20`
    - `/api/v1/assign-revoke/log/{id}` # Note: The ID is the primary key, not the campus ID.
    """

    queryset = ARLog.objects.all()
    serializer_class = LogSerializer
