import os

from django.db import models  # noqa: F401
from model_utils.models import TimeStampedModel
from sat.slack import Slack
from simple_history.models import HistoricalRecords

# Create your models here.


class ServiceAccount(TimeStampedModel):
    created_by = models.EmailField(max_length=254)
    service_name = models.CharField(max_length=32, null=True, blank=False)
    service_account_data = models.JSONField()
    history = HistoricalRecords()

    def __str__(self):
        return f"{self.service_account_data['client_email']}"

    @property
    def client_email(self):
        return self.service_account_data.get("client_email", "")

    @property
    def client_x509_cert_url(self):
        return self.service_account_data.get("client_x509_cert_url", "")


class SlackChannel(TimeStampedModel):
    channel_name = models.CharField(max_length=32, null=True, blank=False)
    channel_id = models.CharField(max_length=32, null=True, blank=False)
    slack_token = models.CharField(max_length=64, null=True, blank=False)

    def __str__(self):
        return f"{self.channel_name} ({self.channel_id})"

    def send_message(self, message):
        slack = Slack(self.slack_token)
        # only the staging cluster has this environment variable
        if os.getenv("ENVIRONMENT") == "staging":
            prepended_message = "STAGING: " + message
        else:
            prepended_message = "PROD: " + message
        slack.send_message(self.channel_id, prepended_message)
