import os

from acslib.ccure import CcureConnection
from acslib.ccure.config import CcureConfigFactory
from django.conf import settings

GOLD_PRTG_BASE_URL = settings.GOLD_PRTG_BASE_URL
GOLD_PRTG_GUID = settings.GOLD_PRTG_GUID
GOLD_PRTG_URL = f"{settings.GOLD_PRTG_BASE_URL}/{settings.GOLD_PRTG_GUID}"
CLEARANCE_SERVICE_URL = settings.CLEARANCE_SERVICE_URL
PEOPLESOFT_PROXY_URL = settings.PEOPLESOFT_PROXY_URL
AUTH_SERVICE_URL = settings.AUTH_SERVICE_URL
DEFAULT_FROM_EMAIL = settings.DEFAULT_FROM_EMAIL
SENDGRID_API_KEY = settings.SENDGRID_API_KEY

CCURE_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.CCURE_SERVER};"
    f"PORT={settings.CCURE_PORT};"
    f"UID={settings.CCURE_USERNAME};"
    f"PWD={settings.CCURE_PASSWORD};"
)

GOLD_CONNECTION = {
    "user": settings.GOLD_DB_USERNAME,
    "password": settings.GOLD_DB_PASSWORD,
    "dsn": settings.GOLD_DB_DSN,
}

FEED_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.FEED_SERVER};"
    f"PORT={settings.FEED_PORT};"
    f"UID={settings.FEED_USERNAME};"
    f"PWD={settings.FEED_PASSWORD};"
)

FMI_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.FMI_SERVER};"
    f"PORT={settings.FMI_PORT};"
    f"UID={settings.FMI_USERNAME};"
    f"PWD={settings.FMI_PASSWORD};"
)

DIESTER_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.DIESTER_SERVER};"
    f"PORT={settings.DIESTER_PORT};"
    f"UID={settings.DIESTER_USERNAME};"
    f"PWD={settings.DIESTER_PASSWORD};"
)

HRPD_CONNECTION = {
    "user": settings.GOLD_DB_USERNAME,
    "password": settings.GOLD_DB_PASSWORD,
    "dsn": settings.GOLD_DB_DSN,
}

CSPRD_CONNECTION = {
    "user": settings.CSPRD_DB_USERNAME,
    "password": settings.CSPRD_DB_PASSWORD,
    "dsn": settings.CSPRD_DB_DSN,
}

FORPT_CONNECTION = {
    "user": settings.FORPT_DB_USERNAME,
    "password": settings.FORPT_DB_PASSWORD,
    "dsn": settings.FORPT_DB_DSN,
}

GENETEC_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.GENETEC_SERVER};"
    f"PORT={settings.GENETEC_PORT};"
    f"UID={settings.GENETEC_USERNAME};"
    f"PWD={settings.GENETEC_PASSWORD};"
)

SIMS_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.SIMS_SERVER};"
    f"PORT={settings.SIMS_PORT};"
    f"UID={settings.SIMS_USERNAME};"
    f"PWD={settings.SIMS_PASSWORD};"
)

DEISTER_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.DEISTER_SERVER};"
    f"PORT={settings.DEISTER_PORT};"
    f"UID={settings.DEISTER_USERNAME};"
    f"PWD={settings.DEISTER_PASSWORD};"
)

FMI_CONNECTION = (
    "DRIVER=FreeTDS;"
    f"SERVER={settings.FMI_SERVER};"
    f"PORT={settings.FMI_PORT};"
    f"UID={settings.FMI_USERNAME};"
    f"PWD={settings.FMI_PASSWORD};"
)

HRPD_CONNECTION = {
    "user": settings.HRPD_DB_USERNAME,
    "password": settings.HRPD_DB_PASSWORD,
    "dsn": settings.HRPD_DB_DSN,
}

CSPRD_CONNECTION = {
    "user": settings.CSPRD_DB_USERNAME,
    "password": settings.CSPRD_DB_PASSWORD,
    "dsn": settings.CSPRD_DB_DSN,
}

FORPT_CONNECTION = {
    "user": settings.FORPT_DB_USERNAME,
    "password": settings.FORPT_DB_PASSWORD,
    "dsn": settings.FORPT_DB_DSN,
}

AZURE_BLOB_ACCOUNT_URL = settings.AZURE_BLOB_ACCOUNT_URL
AZURE_BLOB_SHARED_ACCESS_KEY = settings.AZURE_BLOB_SHARED_ACCESS_KEY


def get_acslib_connection() -> CcureConnection:
    # ACSLIB CONFIGURATION
    # SAT_AUTOMATIONS uses 2 types of connection to CCURE
    # 1 via the database connection
    # 1 via the ACSLIB
    # Both have similar environment variable requirements, so we need to
    # namespace here.
    # ConfigFactory ensures that we get the correct API endpoints version
    config = CcureConfigFactory(
        CCURE_USERNAME=os.getenv("ACSLIB_CCURE_USERNAME"),
        CCURE_PASSWORD=os.getenv("ACSLIB_CCURE_PASSWORD"),
        CCURE_BASE_URL=os.getenv("ACSLIB_CCURE_BASE_URL"),
        CCURE_CLIENT_NAME=os.getenv("ACSLIB_CCURE_CLIENT_NAME"),
        CCURE_CLIENT_VERSION=os.getenv("ACSLIB_CCURE_CLIENT_VERSION"),
        CCURE_CLIENT_ID=os.getenv("ACSLIB_CCURE_CLIENT_ID"),
    )
    return CcureConnection(config=config)
