import datetime
from typing import Optional

# UserFeed Queries

FEED_INSERT_QUERY = """
        INSERT INTO DataFeed.dbo.UserFeed(
        [PatronID]
        ,[CampusID]
        ,[FirstName]
        ,[MiddleName]
        ,[LastName]
        ,[Classification]
        ,[Email]
        ,[Type]
        ,[Department]
        ,[PersonnelType]
        ,[ProxCardID]
        ,[CIDC]
        ,[GoldTimeStamp]
        )
        VALUES (
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?,
        ?
        )
        """


# CCURE Queries
def return_ccure_user_query(campus_id_str_list):
    ccureUserQuery = f"""
                    SELECT
                        cre.CardInt1 AS "PatronID",
                        p.text1 AS "CampusID",
                        p.FirstName AS "FirstName",
                        p.LastName AS "LastName",
                        p.MiddleName AS "MiddleName",
                        p.text16 AS "Classification",
                        p.text14 AS "Email",
                        pudf.Department_ AS "Department",
                        pt.Name AS "PersonnelType",
                        cre.CardNumber AS "ProxCardID",
                        p.text12 AS "CIDC"
                    FROM
                        ACVSCore.Access.Personnel AS p
                        INNER JOIN ACVSCore.Access.PersonnelType AS pt WITH ( nolock ) ON p.PersonnelTypeID = pt.ObjectID
                        LEFT JOIN acvscore.access.PersonnelUDF AS pudf WITH ( nolock ) ON p.ObjectID = pudf.ObjectID
                        INNER JOIN ACVSCore.Access.Credential AS cre WITH ( nolock ) ON p.ObjectID = cre.PersonnelId
                    WHERE
                        p.text12 in ({campus_id_str_list})
                    """
    return ccureUserQuery


CCURE_ALL_RECORDS_QUERY = """
    SELECT
        PR.ObjectID as "object_id",
        PR.PersonnelTypeID as "personnel_type_id",
        PR.GUID as "guid",
        PR.Name as "name",
        PR.Text1 as "campus_id",
        PR.Disabled as "is_disabled"
    FROM
        ACVScore.Access.Personnel PR
    WHERE PR.Text1 <> ''
    ORDER BY PR.LastModifiedTime DESC"""


CCURE_ALL_IDS_QUERY = """
    SELECT
        PR.Text1 as "campus_id"
    FROM
        ACVScore.Access.Personnel PR
    WHERE PR.Text1 <> ''
    ORDER BY PR.LastModifiedTime DESC"""

CCURE_LAST_USED_QUERY = """
    SELECT
        ci.LastUsedOrResetDate AS "last_used",
        p.Text1 AS "campus_id"
    FROM
        ACVSCore.[Access].[CredentialInactivity] ci
        INNER JOIN ACVSCore.Access.Personnel p ON ci.PersonnelID = p.ObjectID
    WHERE
        p.Text1 <> ''
    ORDER BY ci.LastUsedOrResetDate"""


CCURE_ACTIVE_PERSONNEL_NO_IMAGE = """
    SELECT
        pr.Text1 AS "campus_id"
    FROM
        ACVScore.Access.Personnel PR
    WHERE
        PR.PrimaryPortrait IS NULL
    AND
        PR.Disabled = 0;
"""


def return_ccure_clearance_items_query(cid: list):
    filt = "WHERE ClearanceID IN (%s)"
    if len(cid) == 1:
        filt = f"WHERE ClearanceID = {cid[0]}"
    else:
        items = ",".join([f"'{str(c)}'" for c in cid])
        filt = filt % items
    return f"""
        SELECT DISTINCT
        D.GUID as door_guid,
        E.GUID as elevator_guid
        FROM ACVSCore.Access.ClearanceItem CID
        LEFT OUTER JOIN ACVSCore.Access.Door D ON CID.DoorID = D.ObjectID
        LEFT OUTER JOIN ACVSCore.Access.Elevator E ON CID.ElevatorID = E.ObjectID
        {filt};
    """


# GOLD Queries
def return_gold_user_query(start_date, end_date):
    return f"""
                -- Working Key History Map
                SELECT
                p.ID_PERS AS "PatronID",
                p.VAL_UNIV_ID AS "CampusID",
                p.VAL_NAM_FIRST AS "FirstName",
                p.VAL_NAM_MIDDLE AS "MiddleName",
                p.VAL_NAM_LAST AS "LastName",
                p.CLASSIFICATION AS "Classification",
                i.DBD_EMAIL AS "Email",
                'EDIT' AS "Type",
                i.LOCAL_DEPARTMENT AS "Department",
                cl.CARDSTOCKTYPE AS "PersonnelType",
                kmh.KEYVALUE AS "ProxCardID",
                p.VAL_UNIV_ID||':0' AS "CIDC",
                kmh.MODIFICATIONDATE AS "UpdateTimeStamp"
                FROM DIEBOLD.PERS p
                LEFT JOIN DIEBOLD.EXTENDEDPATRONINFO i
                    ON p.ID_PERS = i.PATRONID
                LEFT JOIN DIEBOLD.PATRONIMAGES im
                    ON p.ID_PERS = im.PATRONID
                LEFT JOIN DIEBOLD.PATRONCARDLOG cl
                    ON p.ID_PERS = cl.PATRONID
                    AND    POSTDATE > (SELECT (MAX(POSTDATE) -1) FROM PATRONCARDLOG
                                       WHERE POSTDATE <= TO_DATE('{end_date}', 'yyyy-mm-dd hh24:mi:ss'))
                JOIN DIEBOLD.KEYMAPPINGINFO_HISTORY kmh
                    ON p.ID_PERS = kmh.PATRONID
                    AND kmh.MEDIATYPE = 22
                    AND kmh.MODIFICATIONTYPE = 'UPDATE'
                    AND kmh.MODIFICATIONDATE > TO_DATE('{start_date}', 'yyyy-mm-dd hh24:mi:ss')
                    AND kmh.MODIFICATIONDATE <= TO_DATE('{end_date}', 'yyyy-mm-dd hh24:mi:ss')
                UNION
                -- Working CardLog
                SELECT
                p.ID_PERS AS "PatronID",
                p.VAL_UNIV_ID AS "CampusID",
                p.VAL_NAM_FIRST AS "FirstName",
                p.VAL_NAM_MIDDLE AS "MiddleName",
                p.VAL_NAM_LAST AS "LastName",
                p.CLASSIFICATION AS "Classification",
                i.DBD_EMAIL AS "Email",
                'CARD' AS "Type",
                i.LOCAL_DEPARTMENT AS "Department",
                cl.CARDSTOCKTYPE AS "PersonnelType",
                k.KEYVALUE AS "ProxCardID",
                p.VAL_UNIV_ID||':0' AS "CIDC",
                cl.POSTDATE AS "UpdateTimeStamp"
                FROM DIEBOLD.PERS p
                LEFT JOIN DIEBOLD.EXTENDEDPATRONINFO i
                   ON p.ID_PERS = i.PATRONID
                LEFT JOIN DIEBOLD.PATRONIMAGES im
                    ON p.ID_PERS = im.PATRONID
                JOIN DIEBOLD.PATRONCARDLOG cl
                    ON p.ID_PERS = cl.PATRONID
                JOIN DIEBOLD.KEYMAPPINGINFO k
                    ON p.ID_PERS = k.PATRONID
                    AND k.MEDIATYPE = 22
                WHERE
                    cl.POSTDATE > TO_DATE('{start_date}', 'yyyy-mm-dd hh24:mi:ss')
                    AND cl.POSTDATE = (
                        SELECT
                            MAX( POSTDATE )
                        FROM
                            PATRONCARDLOG
                        WHERE
                            PATRONID = p.ID_PERS
                            AND cl.POSTDATE <= TO_DATE('{end_date}', 'yyyy-mm-dd hh24:mi:ss')
                        )
                -- Most Recent Card Activity Filter
                ORDER BY 13 DESC
                """


def return_last_image_update_query(start_date: Optional[datetime.datetime] = None) -> str:
    """
    Query gold for patron ID, picture, and updated_on for all pictures
    updated in the last day
    :param start_date: datetime
    :return: str
    """
    if start_date is None:
        now = datetime.datetime.utcnow()
        start_date = now - datetime.timedelta(days=1)
    start_date_str = start_date.strftime("%Y-%m-%d %H:%M:%S")
    return f"""
    SELECT
        p.VAL_UNIV_ID AS "campus_id",
        im.DBD_IMAGE AS "image",
        im.LASTUPDATE AS "last_update"
    FROM DIEBOLD.PERS p
        LEFT JOIN DIEBOLD.PATRONIMAGES im ON p.ID_PERS = im.PATRONID
    WHERE im.LASTUPDATE >= to_date('{start_date_str}','yyyy-mm-dd hh24:mi:ss')
    AND im.DBD_IMAGE IS NOT NULL
    """


def gold_image_all_select():
    return """
        SELECT
            p.VAL_UNIV_ID AS "campus_id",
            im.DBD_IMAGE AS "image",
            im.LASTUPDATE AS "last_update"
        FROM DIEBOLD.PERS p
            LEFT JOIN DIEBOLD.PATRONIMAGES im ON p.ID_PERS = im.PATRONID
        WHERE im.DBD_IMAGE IS NOT NULL
        ORDER BY im.LASTUPDATE ASC
    """


def get_image_for_id(campus_id: str):
    return f"""
        SELECT
            p.VAL_UNIV_ID AS "campus_id",
            im.DBD_IMAGE AS "image",
            im.LASTUPDATE AS "last_update"
        FROM DIEBOLD.PERS p
            LEFT JOIN DIEBOLD.PATRONIMAGES im ON p.ID_PERS = im.PATRONID
        WHERE p.VAL_UNIV_ID = '{campus_id}'
    """


GOLD_IMAGE_ENTRY_COUNT = (
    "SELECT COUNT(PATRONID) FROM DIEBOLD.PATRONIMAGES WHERE DBD_IMAGE IS NOT NULL"
)


# Journal queries
def get_journal_range(from_dt: str, to_dt: str) -> str:
    """
    Currently this query is run against a MSSQL database. Therefor the microseconds in these dates must be expressed as
    a 3 digit integer. So the %f needs to be a 3 digit integer rather than the default six.

    Index order of the returned columns:
        0 campus_id
        1 prox
        2 message_type
        3 message_utc
        4 server_utc
        5 state_code
        6 primary_object_name
        7 primary_object_type
        8 primary_object_uuid
        9 secondary_object_name
        10 secondary_object_type
        11 secondary_object_uuid

    :param from_dt: %Y-%m-%d %H:%M:%S.%f
    :param to_dt: %Y-%m-%d %H:%M:%S.%f
    :return: str
    """
    return f"""
        SELECT
        PER.Text1 as "campus_id",
        XmlMessage.value('(/LogMessage/CHUID/Card)[1]', 'nvarchar(1000)') as "prox",
        JLV.MessageType as "message_type",
        JLV.MessageUTC as "message_utc",
        JLV.ServerUTC as "server_utc",
        JLV.StateCode as "state_code",
        JLV.PrimaryObjectName as "primary_object_name",
        JLV.PrimaryObjectType as "primary_object_type",
        JLV.PrimaryObjectIdentity as "primary_object_uuid",
        JLV.SecondaryObjectName as "secondary_object_name",
        JLV.SecondaryObjectType as "secondary_object_type",
        JLV.SecondaryObjectIdentity as "secondary_object_uuid"
        FROM ACVSCORE.Access.JournalLogView as JLV
        LEFT JOIN ACVSCore.Access.Personnel as PER on JLV.PrimaryObjectIdentity = PER.GUID OR JLV.SecondaryObjectIdentity = PER.GUID
        WHERE
            JLV.ServerUTC > CAST ( '{from_dt}' AS Datetime )
        AND JLV.ServerUTC <= CAST ( '{to_dt}' AS Datetime )
        AND (
            (
                JLV.MessageType in (
                    'CardAdmitted',
                    'CardRejected',
                    'KeypadCommandActivity',
                    'DoubleSwipe',
                    'ManualAction')
            )
            OR
            (
                JLV.MessageType = 'ObjectChangedState'
                AND JLV.StateCode in ('DoorHeld', 'DoorClosed', 'DoorForced', 'Locked', 'Unlocked')
            )
                )
        ORDER BY JLV.ServerUTC ASC
    """
