import pytest
from pydantic import ValidationError

from sat_automations.utils.common.models import PeoplesoftPerson

TEST_PEOPLESOFT_PERSON = {
    "campus_id": "0018763",
    "first_name": "TEST",
    "middle_name": " ",
    "last_name": "PERSON",
    "classification": "EHRA Non-Faculty",
    "unity": "TESTPERS",
    "email": "testpers@ncsu.edu",
    "current_employee": "Y",
    "department": "EHPS - Security Apps & Tech",
    "ouc": "420501",
    "supervisor_id": "000001234",
    "effective_date": "2023-07-01 00:00:00",
    "current_student": "N",
    "academic_level": "",
    "was_student": "N",
}


def test_peoplesoft_person_valid():
    person = PeoplesoftPerson(**TEST_PEOPLESOFT_PERSON)
    assert person


def test_peoplesoft_person_invalid_missing_field():
    del TEST_PEOPLESOFT_PERSON["campus_id"]
    with pytest.raises(ValidationError):
        PeoplesoftPerson(**TEST_PEOPLESOFT_PERSON)


def test_peoplesoft_person_invalid_wrong_name():
    TEST_PEOPLESOFT_PERSON["supervisor"] = TEST_PEOPLESOFT_PERSON["supervisor_id"]
    del TEST_PEOPLESOFT_PERSON["supervisor_id"]
    with pytest.raises(ValidationError):
        PeoplesoftPerson(**TEST_PEOPLESOFT_PERSON)


def test_peoplesoft_person_invalid_wrong_type():
    TEST_PEOPLESOFT_PERSON["campus_id"] = 18763
    with pytest.raises(ValidationError):
        PeoplesoftPerson(**TEST_PEOPLESOFT_PERSON)
