from datetime import datetime

from sat_automations.utils.common import time
from sat_automations.utils.common.time import DATE_FMT, DATETIME_FMT_MICRO, SATTimeZones


def test_bound_time():
    # Test the bound_time function
    # Default parameters. End of day
    res = time.bound_time(datetime.now())
    assert res == datetime.replace(
        datetime.now(), hour=23, minute=59, second=59, microsecond=999999
    )
    # Test the nearest_day parameter
    res = time.bound_time(datetime.now(), nearest_day=True)
    assert res == datetime.replace(datetime.now(), hour=0, minute=0, second=0, microsecond=0)
    # Test the nearest_hour parameter
    res = time.bound_time(datetime.now(), nearest_hour=True)
    assert res == datetime.replace(datetime.now(), minute=0, second=0, microsecond=0)
    # Test the nearest_minute parameter
    res = time.bound_time(datetime.now(), nearest_minute=True)
    assert res == datetime.replace(datetime.now(), second=0, microsecond=0)
    # Test the nearest_second parameter
    res = time.bound_time(datetime.now(), nearest_second=True)
    assert res == datetime.replace(datetime.now(), microsecond=0)


def test_date_as_datetime_utc():
    # Test the date_as_datetime function
    res = time.date_as_datetime("2021-01-01")
    assert res == datetime.strptime("2021-01-01", DATE_FMT).replace(tzinfo=SATTimeZones.UTC.value)


def test_date_as_datetime_ept():
    # Test the date_as_datetime function
    res = time.date_as_datetime("2021-01-01", SATTimeZones.EPT)
    assert res == datetime.strptime("2021-01-01", DATE_FMT).replace(tzinfo=SATTimeZones.EPT.value)


def test_datetime_as_datestr():
    # Test the datetime_as_datestr function
    res = time.datetime_as_datestr(datetime.now())
    assert res == datetime.now().strftime(DATE_FMT)


def test_datetime_as_timestr_micro():
    # Test the datetime_as_datestr function with microseconds
    now = datetime.now()
    res = time.datetime_as_timestr(now, trunc_micro=3)
    assert res == now.strftime(DATETIME_FMT_MICRO)[:-3]


def test_datetime_as_timestr_no_micro():
    # Test the datetime_as_datestr function without microseconds
    now = datetime.now()
    res = time.datetime_as_timestr(now)
    assert res == now.strftime(DATETIME_FMT_MICRO)
